import { Component, OnInit } from '@angular/core';
import { NzMessageService } from 'ng-zorro-antd';
import { ModalHelper } from '@delon/theme';
import { HttpClient } from '@angular/common/http';
import * as moment from 'moment';
import { UserInstallerEditComponent } from './edit/edit.component';
import { environment } from '../../../../environments/environment';

@Component({
  selector: 'app-installer',
  templateUrl: './installer.component.html',
  styles: []
})
export class InstallerComponent implements OnInit {

  q: any = {
    pi: 1,
    ps: 10,
    sorter: '',
    u_name: '',
    u_mobile: ''
  };
  data: any[] = [];
  total: 0;
  selectedRows: any[] = [];
  curRows: any[] = [];
  allChecked = false;
  indeterminate = false;
  sortMap: any = {};

  constructor(
    public http: HttpClient,
    public msgSrv: NzMessageService,
    private modalHelper: ModalHelper) {}

  ngOnInit() {
    this.load();
  }

  load(reload: boolean = false) {
    if (reload) {
      this.q.pi = 1;
    }
    this.http.get(environment.SERVER_BASH_URL + '/user/operate_user', this.q).subscribe((res: any) => {

      let data = res.data;
      const total = res.total;

      if (this.q.sorter !== '') {
        const s = this.q.sorter.split('_');
        data.sort((prev, next) => {
          if (s[1] === 'descend') {
            return moment(next[s[0]]).unix() - moment(prev[s[0]]).unix();
          }
          return moment(prev[s[0]]).unix() - moment(next[s[0]]).unix();
        });
      }

      if (this.q.u_name) {
        data = data.filter(d => d.name.indexOf(this.q.u_name) > -1);
      }
      if (this.q.u_mobile) {
        data = data.filter(d => d.mobile.toString().indexOf(this.q.u_mobile) > -1);
      }

      const start = (this.q.pi - 1) * this.q.ps;
      this.data = data.slice(start, start + this.q.ps);
      this.total = total;
    });
  }

  edit(user) {
    this.modalHelper.static(UserInstallerEditComponent, { user }).subscribe(() => {
      this.load(true);
      this.msgSrv.success('安装用户修改成功！');
    });
  }

  add() {
    const user = {};
    this.modalHelper.static(UserInstallerEditComponent, { user }).subscribe(() => {
      this.load(true);
      this.msgSrv.success('安装用户保存成功！');
    });
  }

  delete(user) {
    this.http.delete(environment.SERVER_BASH_URL + '/user/operate_user/' + user.id).subscribe((res: any) => {
      this.msgSrv.success('安装用户删除成功！');
      this.load(true);
    });
  }

  remove() {
    this.selectedRows.forEach(i => {
      this.http.delete(environment.SERVER_BASH_URL + '/user/operate_user/' + i.id).subscribe((res: any) => {
        // TODO
      });
    });
    this.load(true);
  }

  checkAll(value: boolean) {
    this.curRows.forEach(i => {
      if (!i.disabled) i.checked = value;
    });
    this.refreshStatus();
  }

  refreshStatus() {
    const allChecked = this.curRows.every(value => value.disabled || value.checked);
    const allUnChecked = this.curRows.every(value => value.disabled || !value.checked);
    this.allChecked = allChecked;
    this.indeterminate = (!allChecked) && (!allUnChecked);
    this.selectedRows = this.data.filter(value => value.checked);
  }

  sort(field: string, value: any) {
    this.sortMap = {};
    this.sortMap[field] = value;
    this.q.sorter = value ? `${field}_${value}` : '';
    this.load(true);
  }

  reset(ls: any[]) {
    for (const item of ls) item.value = false;
    this.load(true);
  }
}
